@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 from __future__ import print_function
 
 import re
@@ -27,7 +26,8 @@ __all__ = [
 __additional_methods__ = {
     str: {
         'length': lambda self: len(self),
-        'replaceAll': lambda self, pattern, repl: re.sub(pattern, repl, self)
+        'replaceAll': lambda self, pattern, repl: re.sub(pattern, repl, self),
+        'startsWith': lambda self, prefix: self.startswith(prefix)
     },
     list: {
         'size': lambda self: len(self),
@@ -625,17 +625,29 @@ class NameOrCall(_Element):
 
 
 class SubExpression(_Element):
-    DOT = re.compile('\.(.*)', re.S)
+    DOT = re.compile(r'\.(.*)', re.S)
 
     def parse(self):
-        self.identity_match(self.DOT)
-        self.expression = self.next_element(VariableExpression)
+        try:
+            self.identity_match(self.DOT)
+            self.expression = self.next_element(VariableExpression)
+        except NoMatch:
+            self.expression = self.next_element(ArrayIndex)
+            self.subexpression = None
+            try:
+                self.subexpression = self.next_element(SubExpression)
+            except NoMatch:
+                pass
 
     def calculate(self, current_object, loader, global_namespace):
-        return self.expression.calculate(
-            current_object,
-            loader,
-            global_namespace)
+        args = [current_object, loader]
+        if not isinstance(self.expression, ArrayIndex):
+            return self.expression.calculate(*(args + [global_namespace]))
+        index = self.expression.calculate(*args)
+        result = current_object[index]
+        if self.subexpression:
+            result = self.subexpression.calculate(result, loader, global_namespace)
+        return result
 
 
 class VariableExpression(_Element):
@@ -750,7 +762,7 @@ class Null:
 
 class Comment(_Element, Null):
     COMMENT = re.compile(
-        '#(?:#.*?(?:\n|$)|\*.*?\*#(?:[ \t]*\n)?)(.*)$',
+        '#(?:#.*?(?:\n|$)|\\*.*?\\*#(?:[ \t]*\n)?)(.*)$',
         re.M +
         re.S)
 
